@@ -1,4 +1,4 @@
-//@line 38 "/builds/tinderbox/Fx-Trunk/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/base/content/pageinfo/feeds.js"
+//@line 38 "/builds/slave/mozilla-1.9.1-linux-nightly/build/browser/base/content/pageinfo/feeds.js"
 
 function initFeedTab()
 {
@@ -26,10 +26,10 @@ function initFeedTab()
     }
 
     if (rels.feed || (link.type && rels.alternate && !rels.stylesheet)) {
-      var feed = { title: link.title, href: link.href, type: link.type || "" };
-      if (isValidFeed(feed, gDocument.nodePrincipal, rels.feed)) {
-        var type = feedTypes[feed.type] || feedTypes["application/rss+xml"];
-        addRow(feed.title, type, feed.href);
+      var type = isValidFeed(link, gDocument.nodePrincipal, rels.feed);
+      if (type) {
+        type = feedTypes[type] || feedTypes["application/rss+xml"];
+        addRow(link.title, type, link.href);
       }
     }
   }
