@@ -1,4 +1,4 @@
-//@line 36 "/builds/tinderbox/Fx-Trunk/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/base/content/pageinfo/permissions.js"
+//@line 36 "/builds/slave/mozilla-1.9.1-linux-nightly/build/browser/base/content/pageinfo/permissions.js"
 const ALLOW = nsIPermissionManager.ALLOW_ACTION;   // 1
 const BLOCK = nsIPermissionManager.DENY_ACTION;    // 2
 const SESSION = nsICookiePermission.ACCESS_SESSION;// 8
@@ -32,6 +32,10 @@ var gPermObj = {
     if (gPrefs.getBoolPref("xpinstall.whitelist.required"))
       return BLOCK;
     return ALLOW;
+  },
+  geo: function getGeoDefaultPermissions()
+  {
+      return BLOCK;
   }
 };
 
