@@ -104,9 +104,9 @@ function setLabelForNode(aNode, aLabel, aIsLabelFlag)
 function commonDialogOnLoad()
 {
   // set the document title
-//@line 110 "/builds/tinderbox/Fx-Trunk/Linux_2.6.18-53.1.13.el5_Depend/mozilla/toolkit/content/commonDialog.js"
+//@line 110 "/builds/slave/mozilla-1.9.1-linux-nightly/build/toolkit/content/commonDialog.js"
   document.title = gCommonDialogParam.GetString(12);
-//@line 112 "/builds/tinderbox/Fx-Trunk/Linux_2.6.18-53.1.13.el5_Depend/mozilla/toolkit/content/commonDialog.js"
+//@line 112 "/builds/slave/mozilla-1.9.1-linux-nightly/build/toolkit/content/commonDialog.js"
 
   // set the number of command buttons
   var nButtons = gCommonDialogParam.GetInt(2);
@@ -168,9 +168,9 @@ function commonDialogOnLoad()
     // Set the default button and focus it on non-OS X systems
     var dButton = dlgButtons[gCommonDialogParam.GetInt(5)];
     document.documentElement.defaultButton = dButton;
-//@line 174 "/builds/tinderbox/Fx-Trunk/Linux_2.6.18-53.1.13.el5_Depend/mozilla/toolkit/content/commonDialog.js"
+//@line 174 "/builds/slave/mozilla-1.9.1-linux-nightly/build/toolkit/content/commonDialog.js"
     document.documentElement.getButton(dButton).focus();
-//@line 176 "/builds/tinderbox/Fx-Trunk/Linux_2.6.18-53.1.13.el5_Depend/mozilla/toolkit/content/commonDialog.js"
+//@line 176 "/builds/slave/mozilla-1.9.1-linux-nightly/build/toolkit/content/commonDialog.js"
   }
 
   if (gCommonDialogParam.GetInt(6) != 0) // delay button enable
@@ -193,6 +193,16 @@ function commonDialogOnLoad()
   }
 
   getAttention();
+
+  // play sound
+  try {
+    var sound = gCommonDialogParam.GetString(13);
+    if (sound) {
+      Components.classes["@mozilla.org/sound;1"]
+                .createInstance(Components.interfaces.nsISound)
+                .playSystemSound(sound);
+    }
+  } catch (e) { }
 }
 
 var gDelayExpired = false;
